use std::collections::HashMap;

use serde::{Deserialize, Serialize};

const DATA: &'static str = include_str!("../data.json");

#[derive(Serialize, Deserialize, Debug)]
pub struct Data {
    pub db_data: SubData,
    pub fish_entries: Vec<FishMeta>,
}

#[derive(Serialize, Deserialize, Debug)]
pub struct SubData {
    #[serde(alias = "FISH")]
    pub fish: HashMap<u32, FishEntry>,
}

#[derive(Serialize, Deserialize, Debug)]
#[serde(rename_all(deserialize = "camelCase"))]
pub struct FishEntry {
    #[serde(alias = "_id")]
    pub id: u32,
    pub start_hour: Option<f32>,
    pub end_hour: Option<f32>,
    pub location: Option<u32>,
}

#[derive(Serialize, Deserialize, Debug)]
pub struct Location {
    pub id: u32,
    pub name_en: String,
    pub map_coords: (f32, f32, u32),
}

#[derive(Serialize, Deserialize, Debug)]
pub struct FishMeta {
    pub id: u32,
    pub name_en: String,
}

impl Data {
    pub fn new() -> Self {
        let json = serde_json::from_str(DATA).unwrap();
        json
    }
}
